==> libapache-poi-java_3.10.1.orig.tar.xz: apache-poi-3.10.1/src/ooxml/testcases/org/apache/poi/xssf/usermodel/AllXSSFUsermodelTests.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xssf.usermodel;

import org.apache.poi.xssf.usermodel.extensions.TestXSSFBorder;
import org.apache.poi.xssf.usermodel.extensions.TestXSSFCellFill;
import org.apache.poi.xssf.usermodel.extensions.TestXSSFSheetComments;
import org.apache.poi.xssf.usermodel.helpers.TestColumnHelper;
import org.apache.poi.xssf.usermodel.helpers.TestHeaderFooterHelper;
import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * Collects all tests for <tt>org.apache.poi.xssf.usermodel</tt> and sub-packages.
 */
@RunWith(Suite.class)
@Suite.SuiteClasses({
    TestFormulaEvaluatorOnXSSF.class,
    TestSheetHiding.class,
    TestXSSFBugs.class,
    TestXSSFDataFormat.class,
    TestXSSFCellStyle.class,
    TestXSSFComment.class,
    TestXSSFDialogSheet.class,
    TestXSSFDrawing.class,
    TestXSSFFont.class,
    TestXSSFFormulaEvaluation.class,
    TestXSSFHeaderFooter.class,
    TestXSSFHyperlink.class,
    TestXSSFName.class,
    TestXSSFPicture.class,
    TestXSSFPictureData.class,
    TestXSSFPrintSetup.class,
    TestXSSFRichTextString.class,
    TestXSSFRow.class,
    TestXSSFSheet.class,
    TestXSSFSheetUpdateArrayFormulas.class,
    TestXSSFWorkbook.class,
    TestXSSFBorder.class,
    TestXSSFCellFill.class,
    TestXSSFSheetComments.class,
    TestColumnHelper.class,
    TestHeaderFooterHelper.class    
})
public final class AllXSSFUsermodelTests {
}

==> libapache-poi-java_3.12.orig.tar.xz: apache-poi-3.12/src/ooxml/testcases/org/apache/poi/xssf/usermodel/AllXSSFUsermodelTests.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xssf.usermodel;

import org.apache.poi.xssf.usermodel.extensions.TestXSSFBorder;
import org.apache.poi.xssf.usermodel.extensions.TestXSSFCellFill;
import org.apache.poi.xssf.usermodel.extensions.TestXSSFSheetComments;
import org.apache.poi.xssf.usermodel.helpers.TestColumnHelper;
import org.apache.poi.xssf.usermodel.helpers.TestHeaderFooterHelper;
import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * Collects all tests for <tt>org.apache.poi.xssf.usermodel</tt> and sub-packages.
 */
@RunWith(Suite.class)
@Suite.SuiteClasses({
    TestFormulaEvaluatorOnXSSF.class,
    TestMultiSheetFormulaEvaluatorOnXSSF.class,
    TestSheetHiding.class,
    TestXSSFBugs.class,
    TestXSSFDataFormat.class,
    TestXSSFCellStyle.class,
    TestXSSFComment.class,
    TestXSSFDialogSheet.class,
    TestXSSFDrawing.class,
    TestXSSFFont.class,
    TestXSSFFormulaEvaluation.class,
    TestXSSFHeaderFooter.class,
    TestXSSFHyperlink.class,
    TestXSSFName.class,
    TestXSSFPicture.class,
    TestXSSFPictureData.class,
    TestXSSFPrintSetup.class,
    TestXSSFRichTextString.class,
    TestXSSFRow.class,
    TestXSSFSheet.class,
    TestXSSFSheetUpdateArrayFormulas.class,
    TestXSSFTable.class,
    TestXSSFWorkbook.class,
    TestXSSFBorder.class,
    TestXSSFCellFill.class,
    TestXSSFSheetComments.class,
    TestColumnHelper.class,
    TestHeaderFooterHelper.class,
    TestXSSFPivotTable.class
})
public final class AllXSSFUsermodelTests {
}
